#!/usr/bin/env python
# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003-2004 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


# Internationalization
from Mattricks import I18n

I18n.install_translation()

from distutils.core import setup
try:
    import py2exe
    py2exe = True
except ImportError:
    py2exe = False

from Mattricks import Version
from Mattricks import Countries

import re
import string

if py2exe:
    try:
        import sys
        import modulefinder
        import win32com
        for p in win32com.__path__[1:]:
            modulefinder.AddPackagePath("win32com", p)
        for extra in ["win32com.shell","win32com.mapi"]:
            __import__(extra)
            m = sys.modules[extra]
            for p in m.__path__[1:]:
                modulefinder.AddPackagePath(extra, p)
    except ImportError:
        # no build path setup, no worries.
        pass

def convert_files(files, vartable, varlisttable):
    re_fdd = re.compile("###(.*?)###", re.DOTALL | re.MULTILINE)

    for infile, outfile in files:
        f = open(infile, 'r')
        fdata = f.read()
        f.close()

        m = re_fdd.search(fdata)
        while m:
            s = m.group(1)
            res = ""
            for var, valuelist in varlisttable:
                re_var = re.compile("#" + var + "#", re.DOTALL | re.MULTILINE)
                m2 = re_var.search(s)
                if m2:
                    for value in valuelist:
                        res += s.replace("#" + var + "#", str(value))
            fdata = fdata[:m.start(0)] + res + fdata[m.end(0):]
            m = re_fdd.search(fdata)

        for var, value in vartable:
            fdata = fdata.replace("#" + var + "#", str(value))

        f = open(outfile, 'w')
        f.write(fdata)
        f.close()

def crlf_convert_file(filename):
    content = open(filename, 'r').read()
    content = string.join(content.splitlines() + [''], "\r\n")
    open(filename, 'w').write(content)

if Version.version_type == "cvs":
    VERSION = Version.version + Version.cvsdate_str
else:
    VERSION = Version.version

real_version = VERSION
if py2exe:
    VERSION = str(Version.version_major) + "." + str(Version.version_minor)


DESCRIPTION = """\
Mattricks is an attempt to create a free helper program for hattricks players
with a multitude of tools to help fetching data, comparing and other things.
The program is currently under heavy development.
"""

languages = ["sv", "pl", "nl", "de", "it", "es"]

lang_files = []
for l in languages:
    lang_files.append(("share/locale/%s/LC_MESSAGES" % l,
                       ["locale/%s/LC_MESSAGES/mattricks.mo" % l]))

convert_files([("scripts/mattricks.iss.in", "scripts/mattricks.iss"),
               ("debian/changelog.in", "debian/changelog")],
              [("VERSION", real_version)],
              [("LOCALE", languages)])

all_flags = ["Data/" + f for f in
             filter(lambda f: f != None, list(zip(*Countries.country_info.values())[5]))]

if py2exe:
    for filename in ["AUTHORS", "BUGS", "COPYING", "ChangeLog", "INSTALL", "NEWS", "README", "TODO"]:
        crlf_convert_file(filename)

setup(name="Mattricks",
      version=VERSION,
      license="GPL",
      description="A free helper program for hattrick players.",
      long_description=DESCRIPTION,
      author="Mattricks Team",
      author_email="mattricks@lists.lysator.liu.se",
      url="http://www.lysator.liu.se/mattricks/",
      packages=["Mattricks"],
      scripts=["mattricks.py"],
      windows=[{"script": "mattricks.py",
                "icon_resources": [(1, "scripts/mattricks-icons.ico")]
                }],
      data_files=[("share/Mattricks",
                   ["Data/yellowcard.png", "Data/2yellowcards.png",
                    "Data/redcard.png", "Data/injury.png", "Data/bruised.png",
                    "Data/dress_shirt_body_mask.png",
                    "Data/dress_shirt_fringe_mask.png",
                    "Data/dress_shorts_body_mask.png",
                    "Data/dress_shorts_fringe_mask.png",
                    "Data/dress_socks_body_mask.png",
                    "Data/dress_socks_fringe_mask.png",
                    "Data/arrow_small_down.png", "Data/arrow_small_up.png",
                    "Data/chpp_logotype.png", "Data/football_bg.png",
                    "Data/star.png", "Data/star_half.png",
                    "Data/icon-16x16.png", "Data/icon-32x32.png",
                    "Data/icon-48x48.png", "Data/icon-64x64.png",
                    "Data/mattricks_logotype.png",
                    "Data/weather_cloudy.png", "Data/weather_overcast.png",
                    "Data/weather_rain.png", "Data/weather_sun.png",
                    "Data/soundon.png", "Data/soundoff.png", "Data/eventon.png",
                    "Data/eventoff.png", "Data/glasses.png",
                    "Data/field.png", "Data/matchinfo.png", "Data/out_arrow.png",
                    "Data/in_arrow.png", "Data/left.png", "Data/right.png"
                    ] + all_flags),
#                  ("share/doc/Mattricks-" + VERSION,
#                   ["COPYING", "README", "AUTHORS", "NEWS", "scripts/testfile.hrf"])
                  ] + lang_files)
